@@ -105,9 +105,13 @@ Config::Config() :
     alsaAudioDevice("default"),
     alsaMidiDevice("default"),
     BankUIAutoClose(0),
+    GzipCompression(3),
     Interpolation(0),
     CheckPADsynth(1),
     rtprio(50),
+    midi_bank_C(0),
+    midi_upper_voice_C(128),
+    enable_part_on_voice_load(0),
     deadObjects(NULL),
     sigIntActive(0),
     ladi1IntActive(0),
@@ -353,6 +357,7 @@ bool Config::extractConfigData(XMLwrapper *xml)
                                         MAX_AD_HARMONICS * 2, 131072);
     BankUIAutoClose = xml->getpar("bank_window_auto_close",
                                                BankUIAutoClose, 0, 1);
+    GzipCompression = xml->getpar("gzip_compression", GzipCompression, 0, 9);
     currentBankDir = xml->getparstr("bank_current");
     Interpolation = xml->getpar("interpolation", Interpolation, 0, 1);
     CheckPADsynth = xml->getpar("check_pad_synth", CheckPADsynth, 0, 1);
@@ -427,6 +432,11 @@ bool Config::extractConfigData(XMLwrapper *xml)
     // jack settings
     jackServer = xml->getparstr("linux_jack_server");
 
+    // midi options
+    midi_bank_C = xml->getpar("midi_bank_C", midi_bank_C, 0, 128);
+    midi_upper_voice_C = xml->getpar("midi_upper_voice_C", midi_upper_voice_C, 14, 128);
+    enable_part_on_voice_load = xml->getpar("enable_part_on_voice_load", enable_part_on_voice_load, 0, 1);
+
     if (xml->enterbranch("XMZ_HISTORY"))
     {
         int hist_size = xml->getpar("history_size", 0, 0, MaxParamsHistory);
@@ -458,8 +468,12 @@ void Config::saveConfig(void)
         return;
     }
     addConfigXML(xmltree);
+    unsigned int tmp = GzipCompression;
+    GzipCompression = 0;
     if (!xmltree->saveXMLfile(ConfigFile))
         Log("Failed to save config to " + ConfigFile);
+    GzipCompression = tmp;
+
     delete xmltree;
 }
 
@@ -474,6 +488,7 @@ void Config::addConfigXML(XMLwrapper *xmltree)
     xmltree->addpar("oscil_size", Oscilsize);
     xmltree->addpar("bank_window_auto_close", BankUIAutoClose);
 
+    xmltree->addpar("gzip_compression", GzipCompression);
     xmltree->addpar("check_pad_synth", CheckPADsynth);
     xmltree->addparstr("bank_current", currentBankDir);
     xmltree->addpar("virtual_keyboard_layout", VirKeybLayout);
@@ -499,6 +514,10 @@ void Config::addConfigXML(XMLwrapper *xmltree)
     xmltree->addparstr("linux_alsa_midi_dev", alsaMidiDevice);
     xmltree->addparstr("linux_jack_server", jackServer);
 
+    xmltree->addpar("midi_bank_C", midi_bank_C);
+    xmltree->addpar("midi_upper_voice_C", midi_upper_voice_C);
+    xmltree->addpar("enable_part_on_voice_load", enable_part_on_voice_load);
+
     // Parameters history
     if (ParamsHistory.size())
     {
