@@ -27,6 +27,7 @@ using namespace std;
 
 #include "MasterUI.h"
 #include "Misc/SynthEngine.h"
+#include "Misc/Config.h"
 
 SynthEngine *synth = NULL;
 
@@ -321,21 +322,72 @@ void SynthEngine::NoteOff(unsigned char chan, unsigned char note)
 // Controllers
 void SynthEngine::SetController(unsigned char chan, unsigned int type, short int par)
 {
-    for (int npart = 0; npart < NUM_MIDI_PARTS; ++npart)
-    {   // Send the controller to all part assigned to the channel
-        if (chan == part[npart]->Prcvchn && part[npart]->Penabled)
-            part[npart]->SetController(type, par);
+    if (type == Runtime.midi_bank_C) {
+        /*  we use either msb or lsb for bank changes
+	  128 banks is enough for anybody :-)
+        this is configurable to suit different hardware synths
+        */
+        bank.msb = (unsigned char)par + 1; //Bank indexes start from 1       
+        if(bank.msb <= MAX_NUM_BANKS) {
+            if (bank.loadbank(bank.banks[bank.msb].dir))
+            {
+                Runtime.Log("SynthEngine setBank: Loaded " + bank.banks[bank.msb].name);
+            }
+            else
+            {
+                Runtime.Log("SynthEngine setBank: No bank " + asString(par));
+            }
+        }
+        else
+            Runtime.Log("SynthEngine setBank: Value is out of range!");
+        return;        
     }
+    else
+    { // bank change doesn't directly affect parts.
+	for (int npart = 0; npart < NUM_MIDI_PARTS; ++npart)
+	{   // Send the controller to all part assigned to the channel
+	    if (chan == part[npart]->Prcvchn && part[npart]->Penabled)
+		part[npart]->SetController(type, par);
+	}
 
-    if (type == C_allsoundsoff)
-    {   // cleanup insertion/system FX
-        for (int nefx = 0; nefx < NUM_SYS_EFX; ++nefx)
-            sysefx[nefx]->cleanup();
-        for (int nefx = 0; nefx < NUM_INS_EFX; ++nefx)
-            insefx[nefx]->cleanup();
+	if (type == C_allsoundsoff)
+	{   // cleanup insertion/system FX
+	    for (int nefx = 0; nefx < NUM_SYS_EFX; ++nefx)
+		sysefx[nefx]->cleanup();
+	    for (int nefx = 0; nefx < NUM_INS_EFX; ++nefx)
+		insefx[nefx]->cleanup();
+	}
     }
 }
 
+void SynthEngine::SetProgram(unsigned char chan, unsigned char pgm)
+{
+    if (bank.getname(pgm) < "!") // can't get a program name less than this
+    {
+        Runtime.Log("SynthEngine setProgram: No Program " + asString(pgm));
+    }
+    else
+    {
+        for(int npart = 0; npart < NUM_MIDI_PARTS; ++npart)
+            if(chan == part[npart]->Prcvchn)
+            {
+                if (part[npart]->Penabled == 0 and Runtime.enable_part_on_voice_load != 0)
+                {
+                    partonoff(npart, 1);
+                }
+                bank.loadfromslot(pgm, part[npart]); //Programs indexes start from 0
+            }
+        Runtime.Log("SynthEngine setProgram: Loaded " + bank.getname(pgm));
+        //update UI
+        if (Runtime.showGui)
+        {
+            guiMaster->updatepanel();
+            if (guiMaster->partui && guiMaster->partui->instrumentlabel && guiMaster->partui->part) {
+                guiMaster->partui->instrumentlabel->copy_label(guiMaster->partui->part->Pname.c_str());
+            }
+        }
+    }
+}
 
 // Enable/Disable a part
 void SynthEngine::partonoff(int npart, int what)
@@ -487,8 +539,11 @@ void SynthEngine::MasterAudio(float *outl [NUM_MIDI_PARTS], float *outr [NUM_MID
     {
         for (int i = 0; i < buffersize; ++i)
         {   // the volume did not change
-            outl[NUM_MIDI_PARTS][i] += outl[npart][i];
-            outr[NUM_MIDI_PARTS][i] += outr[npart][i];
+            if (Runtime.AudioSend[npart] & 1)
+            {
+                outl[NUM_MIDI_PARTS][i] += outl[npart][i];
+                outr[NUM_MIDI_PARTS][i] += outr[npart][i];
+            }
         }
     }
 
@@ -953,11 +1008,11 @@ float SynthHelper::getDetune(unsigned char type, unsigned short int coarsedetune
             break;
         case 3:
             cdet = fabsf(cdetune * 100.0f);
-            findet = pow(10.0f, fabs(fdetune / 8192.0f) * 3.0f) / 10.0f - 0.1f;
+            findet = powf(10.0f, fabs(fdetune / 8192.0f) * 3.0f) / 10.0f - 0.1f;
             break;
         case 4:
             cdet = fabs(cdetune * 701.95500087f); // perfect fifth
-            findet = (pow(2.0f, fabs(fdetune / 8192.0f) * 12.0f) - 1.0f) / 4095.0f * 1200.0f;
+            findet = (powf(2.0f, fabs(fdetune / 8192.0f) * 12.0f) - 1.0f) / 4095.0f * 1200.0f;
             break;
             // case ...: need to update N_DETUNE_TYPES, if you'll add more
         default:
