@@ -228,7 +228,13 @@ bool JackEngine::openAudio(void)
     }
 
     if (jackPortsRegistered)
+    {
+        for (int npart = 0; npart < NUM_MIDI_PARTS; ++npart)
+        {
+            Runtime.AudioSend[npart] = 1; // default - only need if running jack audio
+        }
         return prepBuffers(false) && latencyPrep();
+    }
     else
         Runtime.Log("Failed to register jack audio ports");
     Close();
@@ -253,6 +259,11 @@ bool JackEngine::openMidi(void)
         Runtime.Log("Failed to create jack midi ringbuffer");
         return false;
     }
+    if (jack_ringbuffer_mlock(midi.ringBuf))
+    {
+        Runtime.Log("Failed to lock memory");
+        return false;
+    }
     return true;
 }
 
@@ -267,9 +278,9 @@ bool JackEngine::connectJackPorts(void)
         return false;
 	}
     int ret;
-    for (int port = 0; (port < (2 * NUM_MIDI_PARTS)) && (NULL != audio.ports[port]); ++port)
+    for (int port = 0; port < 2 && (NULL != audio.ports[port]); ++port)
     {
-        const char *port_name = jack_port_name(audio.ports[port]);
+        const char *port_name = jack_port_name(audio.ports[port + NUM_MIDI_PARTS * 2]);
         if ((ret = jack_connect(jackClient, port_name, playback_ports[port])))
         {
             Runtime.Log("Cannot connect " + string(port_name)
@@ -335,8 +346,11 @@ bool JackEngine::processAudio(jack_nframes_t nframes)
     getAudio();
     for (int port = 0; port < NUM_MIDI_PARTS; ++port)
     {
-        memcpy(audio.portBuffs[port * 2], zynLeft[port], sizeof(float) * nframes);
-        memcpy(audio.portBuffs[port * 2 + 1], zynRight[port], sizeof(float) * nframes);
+        if (Runtime.AudioSend[port] & 2)
+        {
+            memcpy(audio.portBuffs[port * 2], zynLeft[port], sizeof(float) * nframes);
+            memcpy(audio.portBuffs[port * 2 + 1], zynRight[port], sizeof(float) * nframes);
+        }
     }
     //And mixed outputs
     memcpy(audio.portBuffs[2 * NUM_MIDI_PARTS], zynLeft[NUM_MIDI_PARTS], sizeof(float) * nframes);
@@ -434,7 +448,7 @@ void *JackEngine::midiThread(void)
     if (sem_init(&midiSem, 0, 0) < 0)
     {
         Runtime.Log("Error on jack midi sem_init " + string(strerror(errno)));
-        return false;
+        return NULL;
     }
 
     while (Runtime.runSynth)
@@ -508,6 +522,12 @@ void *JackEngine::midiThread(void)
                 par = midiEvent.data[2];
                 setMidiController(channel, ctrltype, par);
                 break;
+                
+            case 0xC0: // program change
+                ctrltype = C_programchange;
+                par = midiEvent.data[1];
+                setMidiProgram(channel, par);
+                break;
 
             case 0xE0: // pitch bend
                 ctrltype = C_pitchwheel;
