@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2005 Nasca Octavian Paul
-    Copyright 2009-2010, Alan Calvert
+    Copyright 2009-2011, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2010
+    This file is derivative of ZynAddSubFX original code, modified January 2011
 */
 #include <cstring>
 
@@ -31,9 +32,9 @@ Presets::Presets() : nelement(-1)
 }
 
 
-void Presets::setpresettype(const char *type)
+void Presets::setpresettype(const char *type_)
 {
-    strcpy(this->type, type);
+    strcpy(type, type_);
 }
 
 
@@ -41,12 +42,12 @@ void Presets::copy(const char *name)
 {
     XMLwrapper *xml = new XMLwrapper();
 
-    //used only for the clipboard
+    // used only for the clipboard
     if (name == NULL)
         xml->minimal = false;
 
     char type[MAX_PRESETTYPE_SIZE];
-    strcpy(type,this->type);
+    strcpy(type, this->type);
     if (nelement != -1)
         strcat(type, "n");
     if (name == NULL)
